/*==============================================================================
Name: 		 1_Globals.do

Description: Declares globals necesarry for replicating results. 
==============================================================================*/


/*******************************************************************************
 Working directories
*******************************************************************************/

		global atc_folder   "$path"
		global atc_overleaf "$path/Outputs"
		global rawdata   	"$atc_folder/Data/rawdata"
		global databases 	"$atc_folder/Data/Inputs"
		global figures 		"$atc_overleaf/Figures"
		global tables 		"$atc_overleaf/Tables"
	

/*******************************************************************************	
 Global for figures appearance
*******************************************************************************/

	* Not everyone has Stata 18, so figures are very different with respect to previous versions
	if c(version) == 18.0 {
		global graphopt "legend(region(lcolor(none))) graphr(color(white)) ylabel(, nogrid) scheme(s2color)"
	}
	else {
		global graphopt "legend(region(lcolor(none))) graphr(color(white)) ylabel(, nogrid)"
	}
	
/*******************************************************************************
 Insert years required for analysis (DO NOT CHANGE)
*******************************************************************************/

	* Define frequency for baseline VAT analysis (vat_freq can only be "month" or "quearter")
	global vat_freq quarter	
	
	* Span of time for baseline VAT analysis (baseline goes from 2015q1 to 2018q4)
	global vat_since = 15
	global vat_to    = 18													

	* Span of time for baseline analysis on firms' performance (baseline goes from 2014 to 2019)
	global isr_since = 14
	global isr_to    = 19
	
	* Type of panel for treatment/control sample
	global panel_vat balanced_${vat_freq}_${vat_since}${vat_to}
	global panel_isr balanced_${vat_freq}_${isr_since}${isr_to}
	

/*******************************************************************************
 Variables of interest
*******************************************************************************/

	* Vat data
	global var_compliance  withholding withholding_cards tax_total etr dummy_unrefunded unref_balance
	global var_compliance1 withholding tax_total etr dummy_unrefunded unref_balance
	global var_outcomes    revenue tax_sales purchases exem_purchases tax_purchases value_added	
	global var_outcomes1   tax_sales tax_purchases value_added
	global vat_collapse    withholding* tax_total* etr* unref_balance* revenue* tax_sales* purchases* ///
						   tax_purchases* value_added* dummy_unrefunded* exem_purchases*
	
	* Income tax data
	global var_balance 	   current_assets noncurrent_assets current_liab noncurrent_liab 
	global var_investment  inv_net2 prob_inv_net ppe_net2 inv_gross2 prob_inv_gross ppe_gross2
	global var_investment1 inv_net2 prob_inv_net ppe_net2
	global var_performance cash_stock labor_costs pre_tax_profits after_tax_profits 
	global isr_collapse ppe_gross2* ppe_net2* inv_gross2* inv_net2* cash_stock* labor_costs* pre_tax_profits* after_tax_profits* current_assets* ///
					    noncurrent_assets* current_liab* noncurrent_liab* prob_inv_gross* prob_inv_net* financial*	
	
	