/*==============================================================================
Name: 		 4f_Prepare_Programs.do
Description: Define functions for repeated tasks in empirical analysis.
==============================================================================*/


/*******************************************************************************	
 1. Function for import VAT records and prepare dataset for manipulation
*******************************************************************************/

	program import_vat_data
		use "$databases/ISV_reform_panel_${vat_freq}.dta", clear
		
		merge m:1 id using "$databases/firmlevel_TreatStatus.dta", keepusing(treat*) keep(1 3)
		drop _merge
		
		merge m:1 id using "$databases/heterogeneity_traits.dta", ///
			  keepusing(low_cash_${vat_freq}_${vat_since}${vat_to} capital_intensive_${vat_freq}_${vat_since}${vat_to} ///
			  activity_sector exporter category retail manufacturing wholesale services net_below net_below_median) keep(1 3)
		drop _merge
		
		merge m:1 id year using "$databases/Annual_sales.dta", ///
			  keepusing(quantile0_${vat_freq}* quantile1_${vat_freq}* quantile2_${vat_freq}* quantile3_${vat_freq}* quantile4_${vat_freq}*) keep(1 3)
		drop _merge
		
		if "$vat_freq" == "quarter" {
			format quarter %tq
			tsset id quarter
		}
		else if {
			format month %tm
			tsset id month
		}
	end
	
	
/*******************************************************************************	
 2. Function for import income tax records and prepare dataset for manipulation
*******************************************************************************/

	program import_incometax_data
		use "$databases/ISR_reform_panel.dta", clear
		
		merge m:1 id using "$databases/firmlevel_TreatStatus.dta", keepusing(treat*) keep(1 3)
		drop _merge
		
		merge m:1 id using "$databases/heterogeneity_traits.dta", ///
			  keepusing(low_cash_${vat_freq}_${isr_since}${isr_to} capital_intensive_${vat_freq}_${isr_since}${isr_to} ///
			  activity_sector exporter category retail manufacturing wholesale services net_below net_below_median) keep(1 3)
		drop _merge
		
		merge m:1 id year using "$databases/Annual_sales.dta", ///
			  keepusing(quantile0_${vat_freq}* quantile1_${vat_freq}* quantile2_${vat_freq}* quantile3_${vat_freq}*) keep(1 3)
		drop _merge
		
		tsset id year
	end
	
	
