/*=============================================================================
Name: 		 1a_Clean_Databases.do	

Description: This do-file takes raw de-identified datasets from DCC payments, 
			 VAT forms, withholdings, and tax revenue, harmonizes them and creates
			 intermediate datasets that we use later for further analysis.

Input: 	     Base_Mensual_ISV_201101_201912.dta
			 risk_score.dta
			 Base_Mensual_ISV_201101_201912.dta
			 Base_Mensual_SER_201101_201912.dta
			 Recaudación_ISV_2016-2019.dta

Output: 	 Firm_traits.dta
			 ISV_panel.dta
			 Base_Mensual_SER_201101_201912.dta
			 TaxCollection_2016_2019.dta
==============================================================================*/

*------------------- 1. Generate clean ATC data ---------------------------------
 /* We're not currently using this dataset 
 
use "$rawdata/Base_Mensual_ATC_201101_201912.dta", clear

keep id_retenedor id periodo valor_bruto valor_neto impuesto_retenido valor_devolucion nro_preimpreso id_secuencia

tostring periodo, gen(date_s)
gen date_aux = substr(date_s,1,4) + "/" + substr(date_s,5,2) 
gen date = date(date_aux, "YM")
format date %td
drop date_s date_aux

gen month = mofd(date)
format month %tm

sort id month
bys id month: gen n = _n

gcollapse (sum) valor_bruto valor_neto impuesto_retenido valor_devolucion ///
		  (max) n_dcc_transactions = n, by(id periodo month date)

compress
save "$databases/Base_Mensual_ATC_201101_201912_firmlevel.dta", replace

*/

/*------------------- 2. Generate ISV clean data ---------------------------------*/

use "$rawdata/Base_Mensual_ISV_201101_201912.dta", clear

sort id
by id: gen first = _n
keep if first == 1
keep  tipo_ot tamaño_ot departamento codigo_clase clase codigo_seccion seccion id

encode tipo_ot, gen(tipo)
encode tamaño_ot, gen(size)
encode departamento, gen(dept)

encode clase, gen(clase_c)
encode codigo_seccion, gen(codigo_seccion_c)
encode seccion, gen(seccion_c)

recode codigo_clase (1/990 = 1) (1010/3320 = 2) (3510/4390 = 3) (4510/4540 = 4) (4610/4690 = 5) (4711/4799 = 6) ///
   (4910/5630 = 7) (5811/6630 = 8) (6810/8430 = 9) (8510/9329 = 10) (9411/9900 = 11) (. 9988= 12), gen(activity_sector)
replace   activity_sector = 1 if activity_sector == 12 & inlist(codigo_seccion, "A","B")
replace   activity_sector = 2 if activity_sector == 12 & inlist(codigo_seccion, "C")
replace   activity_sector = 3 if activity_sector == 12 & inlist(codigo_seccion, "D","E","F")
replace   activity_sector = 7 if activity_sector == 12 & inlist(codigo_seccion, "H","I")
replace   activity_sector = 8 if activity_sector == 12 & inlist(codigo_seccion, "J","K")
replace   activity_sector = 9 if activity_sector == 12 & inlist(codigo_seccion, "L","M","N","O")
replace   activity_sector = 10 if activity_sector == 12 & inlist(codigo_seccion, "P","Q","R")
replace   activity_sector = 11 if activity_sector == 12 & inlist(codigo_seccion, "S","T","U")
replace   activity_sector = 12 if activity_sector == 12 & inlist(codigo_seccion, "G","Z")

lab def activity_sector 1"Agriculture and extraction" 2"Manufacturing" 3"Utilities and construction" ///
	4"Automotive" 5"Wholesale" 6"Retail" 7"Transportation, housing" 8"Technology and finance" ///
	9"Real estate, tourism" 10"Education, health" 11"Other services" 12"Undeclared sectors", replace
lab val activity_sector activity_sector

drop clase codigo_seccion seccion tipo_ot tamaño_ot departamento

* Risk score
merge 1:1 id using "$rawdata/risk_score.dta"
drop if _merge == 2
drop _merge

gen risk_score = .
replace risk_score = cond(score_tributario == "1: BAJO" | score_tributario == "2: MODERADO", 1, ///
					 cond(score_tributario == "3: SIGNIFICATIVO", 2,						    ///
					 cond(score_tributario == "4: ALTO" | score_tributario == "5: SEVERO", 3, risk_score)))
label def risk_score 1 "Low risk" 2 "Medium risk" 3 "High risk"
label val risk_score risk_score
drop score_tributario

order id, first
save "$databases/Firm_traits.dta", replace



/*------------------------*3. Generate clean ISV data-----------------------------*/

use "$rawdata/Base_Mensual_ISV_201101_201912.dta", clear

drop tipo_ot tamaño_ot departamento codigo_clase clase codigo_seccion seccion fecha_presentación 

*Generate clean date variables
tostring periodo, gen(date_s)
gen date_aux = substr(date_s,1,4) + "/" + substr(date_s,5,2) 
gen date = date(date_aux, "YM")
format date %td
drop date_s date_aux

gen month = mofd(date)
format month %tm

tsset id month

order id date month
compress
save "$databases/ISV_panel.dta", replace



/*------------------------*4. Generate clean SER data-----------------------------*/

use "$rawdata/Base_Mensual_SER_201101_201912.dta", clear

rename *, lower
rename periodo_declaracion periodo
tostring periodo, gen(date_s)
gen date_aux = substr(date_s,1,4) + "/" + substr(date_s,5,2) 
gen date = date(date_aux, "YM")
format date %td
drop date_s date_aux periodo

gen month = mofd(date)
format month %tm
gen year = year(date)

*Check do-file CheckAggregate_v2 to see how we arrive at this correction of basecalculo
gen double basecalculo_correct = .
replace basecalculo_correct = debitofiscal if inrange(year,2011, 2013)
replace basecalculo_correct = 2*debitofiscal if inrange(year,2014, 2016)
replace basecalculo_correct = 10*debitofiscal if inrange(year,2017, 2019)

*Check separate devolution variables
gen diff = devolucion_8_isv_113_2011 - devol_8isv
count if abs(diff)>10 & abs(diff)!=.    // 0 cases - same variable just rounded
drop devolucion_8_isv_113_2011 diff

gen diff = abs(saldo_def_favor_fisco - imptopagar)
count if abs(diff)>10 & abs(diff)!=.    // 0 cases - same variable just rounded
drop saldo_def_favor_fisco diff

drop codigo_impuesto tipodeclaracion nodeclcorrige tasa noresolucion* interes declaracion numero_documento 

order id_retenedor date month basecalculo basecalculo_correct debitofiscal devol_8isv imptopagar multa recargo  
sort id_retenedor date
save "$databases/Base_Mensual_SER_201101_201912.dta", replace



/*------------------------*5. Clean tax collection data---------------------------------------------------*/

use "$rawdata/Recaudación_ISV_2016-2019.dta", clear

/*The variable given by Mes and Ano refer to date of PAYMENT, but not to the period of refence. Sometimes the period of
reference is years before, for a late payment. So we consider the -periodo- variable and drop dates outside the range of interest 
*/
tostring periodo, gen(date_s)
gen date_aux = substr(date_s,1,4) + "/" + substr(date_s,5,2) 
gen date = date(date_aux, "YM")
format date %td
drop date_s date_aux

gen month = mofd(date)
format month %tm

keep if inrange(month, tm(2016m1), tm(2019m11))

drop if _merge == 2								//These are obs that do not have tax collection data on them
drop _merge

sort month id
drop  Mes Mes tamano tipo date
order id month  monto_aduanas monto_tributos id_cuenta_pa01 cuenta_madre id_sub_cuenta_pa01 sub_cuenta impuesto des_impuesto
save "$databases/TaxCollection_2016_2019.dta", replace

