/*=============================================================================
Name: 		 1d_Clean_ISRPN.do

Description: This do-file raw de-identified dataset from personal income tax data, 
			 clean, harmonize, and build balance sheet outcomes. The output is ready 
			 for analysis.

Input: 	     ISRPN11_20_initialclean.dta

Output: 	 ISRPN_workingdatabase.dta
==============================================================================*/


/*--Open clean data--------------------------------------------------------*/
use "$rawdata/ISRPN11_20_initialclean.dta", clear

/*----------Tipo declarante---------------------------------------------------------------------------------------------*/
gen decl_estadofin= comerciante_individual =="Si" | comerciante_individual =="SI" | comerciante_individual =="01" | comerciante_individual =="1" 
label var decl_estadofin "Comerciante individual debe presentar estados financieros"

gen decl_electronic = (id_formulario == 277)
label var decl_electronic "Digital Tax filling"


/*----------Creating gross revenue categories--------------------------------------------*/
gen double total_gross_revenue=total_ing_grav_resul_ejer
label var total_gross_revenue "Total gross income (ingreso gravable, excluye ingreso no gravable)"

//**checking consistency*//
egen prueba1=rsum(ingre_acti_mercantiles ingre_por_servicios ingre_por_acti_art20 ingre_sueldos_sala_boni ingre_honora_prof ingre_por_alquileres ingre_inter_no_banc otros_ingre_gravados)
gen ratio1=prueba1/total_ing_grav_resul_ejer
sum ratio1, d
drop prueba1 ratio1

gen double gross_salesgoods=ingre_acti_mercantiles
label var gross_salesgoods "Income from sales of goods"

gen double gross_salesservices=ingre_por_servicios
label var gross_salesgoods "Income from sales of services"

gen double gross_income_agmanu=ingre_por_acti_art20
label var gross_income_agmanu "Income from Agriculture, Manufacture, mining, tourism "

//**checking consistency wiht internal casilla*//
gen ratio1=c30_total_ingr_brutos/ingre_acti_mercantiles 
sum ratio1 if (c30_total_ingr_brutos!=0 & ingre_acti_mercantiles!=0 & decl_electronic==1), d
drop ratio1


/*----------Creating taxable income from gross revenue and deductions---------------------*/

gen double resultado_ejercicio = total_ing_grav_resul_ejer - total_deduc_resul_ejer //Total income - total deductions 
label var resultado_ejercicio "Resultado del ejercicio"

gen double deductions_total = total_deduc_resul_ejer


**total_deducciones are Otros Deducibles del Ejercicio
gen double base_imp_renta_bd=total_utili_resul_ejer+total_perdida_resul_ejer
gen double base_imp_renta = total_utili_resul_ejer+(total_perdida_resul_ejer-total_deducciones)
replace base_imp_renta = 0 if base_imp_renta<=0

gen taxable_income = base_imp_renta


* base_imponible_art_22a base_imponible_art_22_lit_b

/*---------------- Variable of due taxes--------------------------------------------------------------------*/

gen double  taxable_inc_rate      = taxable_income/total_ing_grav_resul_ejer		//Profit rate using "tax base" variable *****************

*Minimum Tax
gen porcentaje_ing_brutos_correct = porcentaje_de_ingresos_brutos  //assuming  porcentage is correctly calculated.


**assuming impuesto_segun_tarifa is correct
gen max_ISR_IM = max(porcentaje_ing_brutos_correct,impuesto_segun_tarifa)	//Maximum between (MinimumTax, LinearIncomeTax)
gen max_AS = max_ISR_IM 						

*Variable indicating which of the taxes is "binding"
gen causa_impuesto = .
replace causa_impuesto = 0 if max(porcentaje_ing_brutos_correct, impuesto_segun_tarifa) == 0
replace causa_impuesto = 1 if max(porcentaje_ing_brutos_correct, impuesto_segun_tarifa) ==impuesto_segun_tarifa & ///
	max(porcentaje_ing_brutos_correct, impuesto_segun_tarifa) > 0
replace causa_impuesto = 2 if max(porcentaje_ing_brutos_correct, impuesto_segun_tarifa) == porcentaje_ing_brutos_correct & ///
	max(porcentaje_ing_brutos_correct, impuesto_segun_tarifa) > 0
cap lab def causa_impuesto 0"Ninguno" 1"Renta"  2"Impuesto Mínimo"
lab val causa_impuesto causa_impuesto

tab causa_impuesto, gen(causa_impuesto_)

gen double impuesto_causado = .
replace impuesto_causado = 0 		 						if causa_impuesto == 0
replace impuesto_causado =impuesto_segun_tarifa				if causa_impuesto == 1
replace impuesto_causado = max_AS 							if causa_impuesto == 2
label var impuesto_causado "Impuesto causado real"

*Variable indicando que base esta causando
clonevar tax_type = causa_impuesto
lab def tax_type 0"Not taxed" 1"Income Tax" 2"Minimum Tax", replace
lab val tax_type tax_type

gen effective_rate     = impuesto_causado/total_gross_revenue	//Tax liability as share of gross revenue

* Pre-tax and After-tax profits
gen double pre_tax_profits 	 = resultado_ejercicio
gen double after_tax_profits = pre_tax_profits - impuesto_causado


/*----------Cost Variables-----------------------------------------------------------------------------------------------------------------*/

***Grouping cost variables****
****Here it is more clear to group for variables filled in the digital form. Not available for paper form. 
egen double labor_costs =rowtotal( c3*_sueldos_salarios c3*_honorarios_prof c3*_honorarios_prof_no_res )
egen double financial=rowtotal(c3*_gastos_intereses )
egen double deprec=rowtotal(c*_gastos_por_depreciacion c*_gastos_amortizacion )
egen double othercost_operation=rowtotal(c*_otros_gastos)
egen double othercost_pricetrans=rowtotal(c*_ajustes_precios_tranf_ing)


egen double prueba1 = rowtotal(labor_costs financial deprec othercost_operation othercost_pricetrans c*_donaciones_por_ley c33_colegios_profesionales c33_cuotas_institutos_jub c33_cotizacion_rap)
gen ratio1 = prueba1/total_deduc_resul_ejer
sum ratio1 if decl_electronic ==1, d
drop ratio1 prueba1


/*----------Assets Variables-----------------------------------------------------------------------------------------------------------------*/

***Sum of items within asset. Should be exact for the digital format (Form  277)
egen double total_assets1 = rowtotal(equivalente_efectivo inversiones_corrientes cta_documento_x_cobrar ///
 inventarios activos_no_corrientes_mv activos_biologicos gastos_pagados_x_ant otros_activos_corr propiedad_planta_equipo ///
 activos_intangibles propiedad_inversion activos_biologicos2 activos_exploracion ctas_doc_x_cobrar inversiones_no_corrientes otros_activos_no_corr)

 **Another sum but with more aggregated items, so that it should be consistent also in the paper forms.
gen double total_assets2 = activos_corrientes+activos_no_corriente
label var total_assets2 "activos_corrientes+activos_no_corriente"

/* Generar total depreciaiciones, provisiones, etc */
gen double total_deprec = depres_amort_deterioro



/* check consistency */
gen double total_net_assets= activos_corrientes+ activos_no_corriente-total_deprec
gen double total_gross_assets=activos_corrientes+ activos_no_corriente
gen prueba1=abs(total_assets1 -total_net_assets)<10
tab prueba1
drop prueba1


/*----------Investment and Capital Expenditure Variables-----------------------------------------------------------------------------------------------------------------*/
gen total_fixed_assets=activos_no_corriente
label var total_fixed_assets "Total fixed assets (Activo no corriente)"
sum total_fixed_assets if total_assets2>0 & decl_estadofin==1 & decl_electronic==1,d


/**different measures of ppe_gross*/
gen ppe_gross=propiedad_planta_equipo // gross PPE reported as assets.
sum ppe_gross if total_assets2>0 & decl_estadofin==1 & decl_electronic==1,d

gen ppe_financing=c547_prestamos_compra_prop+c560_prestamos_compra_prop //loans to finance purchase in PPE_t


/*Depreciacion of Property Plant and Equipment.*/
gen ppe_deprec=c525_depreciacion_acum_prop_eq //depreciation specific to PPE
gen ppe_deterioro=c525_deterioro_acum_prop_eq //deterioro specific to PPE
gen ppe_deprecdeter=ppe_deprec+ppe_deterioro 


**PPE net: net book value of property , plant and equipment.
gen ppe_net=ppe_gross-ppe_deprecdeter // Net PPE only should include depreciation and not deterioration
gen ppe_net1 = ppe_gross - ppe_deprec

**PPE share
gen ppe_share_gross=ppe_gross/total_gross_assets // ppe share over total gross assets
gen ppe_share_net=ppe_net/total_net_assets // net ppe share over total net assets



/*Construct Investment: need firms with two consecutive periods*/
sort id year
bys id: gen yearprevious =year[_n-1]
bys id: gen yearless =year-1

gen consecutive=yearless==yearprevious //marking consecutive 
duplicates drop id year, force //revieew this again
xtset id year

*c525_depreciacion_acum_prop_eq

gen net_inv=(ppe_gross-L1.ppe_gross) 

**PPE_t=PPE_t-1-DEPt+Investment 

gen gross_inv=(ppe_gross-L1.ppe_gross)+ ppe_deprec

gen net_inv_rate=net_inv/L1.total_net_assets //investment rate.


***Same depreciation from one year to the next?
gen samedeprec=depres_amort_deterioro==L1.depres_amort_deterioro
tab samedeprec if total_assets2>0 & consecutive==1

***Same PPE from one year to the next?
gen sameppe=ppe_gross==L1.ppe_gross
tab sameppe if total_assets2>0 & consecutive==1


 /*---CASHFLOW-------------------------------------------------------------------------------------------------------------------*/

gen cash_stock = equivalente_efectivo 
sort id year



/* Current/non-current assets and liabilities */
rename activos_corrientes   current_assets 
rename activos_no_corriente noncurrent_assets
rename pasivos_corrientes   current_liab
rename pasivo_no_corr 	    noncurrent_liab
rename gastos_pagados_x_ant advance_payments
rename inventarios			inventories


/*------------------final Analysis Variables------------------------------------------------------------------------------------------------------------*/

	foreach var of varlist total_gross_revenue labor_costs total_net_assets total_gross_assets inventories /// 
				ppe_gross ppe_net gross_inv net_inv ppe_financing total_fixed_assets cash_stock financial ///
				current_assets noncurrent_assets current_liab noncurrent_liab pre_tax_profits after_tax_profits advance_payments {
					gen `var'_mil = `var' / 1000000
			}
	
gen deduction_mil =  deductions_total/1000000								
gen taxable_mil = taxable_income/1000000									
gen impuesto_mil = impuesto_causado/1000000
												
gen L1total_net_assets_mil=L1.total_net_assets_mil 
gen nonpositive_profit = (taxable_inc_rate<=0 & taxable_inc_rate!=.)

 
**Labeling variables
lab var total_gross_revenue_mil		   "Revenue (Million L)"
lab var deduction_mil 				   "Deduction (Million L)"
lab var pre_tax_profits_mil 		   "Pre-tax profits (Million L)"
lab var after_tax_profits_mil		   "After-tax profits (Million L)"
lab var taxable_inc_rate 			   "Profit Rate"
lab var impuesto_mil 				   "Tax liability (Million L)"
lab var labor_costs_mil				   "Labor cost (Million L)"
lab var id 							   "Número de id de contribuyente"
lab var year 						   "Año de declaración fiscal"
lab var total_net_assets_mil		   "Net Assets (Million L)"
lab var ppe_gross_mil				   "Gross property_plant_equipment (Million L)"
lab var ppe_net_mil					   "Net property_plant_equipment (Million L)"
lab var ppe_financing_mil			   "Loans to pruchase PPE (Million L)"
lab var total_fixed_assets_mil		   "Fixed Assets (Million L)"
lab var ingre_netos_no_grav			   "Ingresos netos no gravados"
lab var total_ing_grav_resul_ejer	   "Ingresos brutos totales resultados del ejercicio"
lab var total_deduc_resul_ejer		   "Deducciones"
lab var impuesto_segun_tarifa		   "Impuesto causado de RENTA"
lab var porcentaje_de_ingresos_brutos  "Impuesto mínimo del 1.5/0.75"
lab var cash_stock_mil 				   "Cash (Million L)"
lab var current_assets_mil 			   "Current assets (Million L)"
lab var noncurrent_assets_mil 		   "Non-current assets (Million L)"
lab var current_liab_mil 	  		   "Current liabilities (Million L)"
lab var noncurrent_liab_mil   		   "Non-current liabilities (Million L)"
lab var inventories_mil 			   "Inventories (Million L)"
lab var financial_mil 				   "Financial costs (Million L)"

sort id year
drop if year > 2019
duplicates drop id year, force

keep id year total_gross_revenue_mil deduction_mil pre_tax_profits_mil after_tax_profits_mil taxable_inc_rate impuesto_mil labor_costs_mil total_net_assets_mil total_gross_assets_mil ppe_gross_mil ppe_net_mil gross_inv_mil net_inv_mil L1total_net_assets_mil cash_stock_mil current_assets_mil noncurrent_assets_mil current_liab_mil noncurrent_liab_mil advance_payments_mil inventories_mil financial_mil

order id year, first  
save "$databases/ISRPN_workingdatabase.dta", replace
