/*=============================================================================
Name: 		 3a_Descriptives_ISV.do

Description: This do-file uses processed de-identified VAT records to produce 
			 tables 1 and A1 and figures 2, A1, and A2.

Input: 	     ISV_reform_panel.dta
			 ISRPN_workingdatabase.dta
			 ISRPJ_workingdatabase.dta
			 Firm_traits.dta
			 
Output: 	 table_shares_top.tex
			 table_descriptive_firmyear_fullperiod.tex
			 composition_sales.pdf
			 composition_purchases.pdf
			 accumulated_balance.pdf
			 histo_share_slides1.pdf
			 scatter_share_intq.pdf
			 box_share_sectors.pdf
			 coefplot_reg_determinants2.pdf
==============================================================================*/


	/*--Open data base---------------------------------------------------------*/
	use "$databases/ISV_panel_vars.dta", clear
		

* ========================== TABLE 1 ========================== 
global descriptive taxable_sales_th gross_liability_th credits_th net_liability_th total_withholding_th ///
	net_payment_th total_withholding_th dummy_with_cards ///
	withholding_cards_th withholding_govt_th withholding_large_th positive_balance positive_flow_balance unrefunded_balance_prev_th 
	
global descr_n unique_firm max_tarj dummy_with_cards_n unit 

preserve 
	gcollapse (sum) total_revenue_th taxable_sales_th gross_liability_th credits_th net_liability_th  total_withholding_th ///
	net_payment_th withholding_cards_th withholding_govt_th withholding_large_th total_anticipated_th ///
	 (max) dummy_with_cards unique_firm max_tarj dummy_with_cards_n change_balance_year endyear_balance positive_balance, by(id year) ///
	 labelformat(#sourcelabel#)
	 
	 merge m:1 id using "$databases/Firm_traits.dta", gen(mergeTraits)
	 merge 1:1 id year using "$databases/ISRPN_workingdatabase.dta", keep(1 3) keepusing(total_gross_revenue_mil deduction_mil impuesto_mil total_net_assets_mil total_gross_assets_mil ppe_gross_mil ppe_net_mil gross_inv_mil net_inv_mil L1total_net_assets_mil) gen(mergePN)
	merge 1:1 id year using  "$databases/ISRPJ_workingdatabase.dta", keep(1 3 4 5) keepusing(total_gross_revenue_mil deduction_mil impuesto_mil taxable_inc_rate labor_costs_mil labor_nd_mil net_labor_mil total_net_assets_mil total_gross_assets_mil ppe_gross_mil ppe_net_mil gross_inv_mil net_inv_mil  L1total_net_assets_mil ) gen(mergePJ) update replace

	gen filed_incometax = (mergePN != 1 | mergePJ!=1)
	gen corporate = (tipo == 1)
	gen small = (size == 3)
	gen unit = 1
	gen manufacturing = (activity_sector == 2)
	gen wholesale     = (activity_sector == 5)
	gen retail 		  = (activity_sector == 6)
	gen services      = inrange(activity_sector,7,11) 
	gen dummy_with_cards_panel = dummy_with_cards*100
	gen positive_balance_panel = positive_balance*100
	
	
	gen share_unrefunded = endyear_balance/taxable_sales_th						//Unrefunded stock of credits as % of taxable sales
	lab var share_unrefunded 		"Unrefunded stock (\% taxable sales)"
	lab var corporate        		"Corporation"
	lab var small			 		"Official size: small"
	lab var retail        			"Sector: Retail"
	lab var manufacturing 			"Sector: Manufacturing"
	lab var wholesale        		"Sector: Wholesale"
	lab var services        		"Sector: Services"
	lab var filed_incometax  		"Filed yearly income tax"
	lab var dummy_with_cards_panel 	"Claims Digital Payment withholding (\%)"
	lab var positive_balance_panel 	"Claims positive unrefunded balance (\%)"
	lab var withholding_cards_th   	"Digital payment withholding (L 1,000s)"
	lab var change_balance_year  	"Yearly change in unrefunded balance (L1,000s)"
	lab var endyear_balance  		"Unrefunded balance in December (L1,000s)"
	
	*Three panels:
	global descriptive_sh corporate small services retail manufacturing wholesale  filed_incometax 
	global descriptive total_revenue_th taxable_sales_th gross_liability_th credits_th net_liability_th total_withholding_th ///
		  withholding_cards_th withholding_govt_th withholding_large_th ///
		  net_payment_th dummy_with_cards_panel positive_balance_panel endyear_balance 
		
	global descr_n unit  
	
	eststo drop *

		foreach x of numlist 15 16 17 18 {
			eststo stats_`x': quietly estpost summarize $descriptive_sh if year == (2000+`x'),d
		}

	esttab stats_*  using "$tables/table_descriptive_firmyear_fullperiod.tex",  ///
		cells("mean(fmt(%12.2fc))") mtitles("2015" "2016" "2017" "2018") nonum ///
		refcat(corporate "\emph{Panel A: Firm characteristics}" total_revenue_th "\emph{Panel B: VAT descriptives}" total_withholding_th "\emph{Panel C: Withholding}"  ///
		positive_balance "\emph{Panel D: Unrefunded credit}", nolabel) /// 
		label replace f booktabs brackets gap noobs ///
		starlevels(* 0.1 ** 0.05 *** 0.01) collabels(none)	
		
		
	eststo drop *

		foreach x of numlist 15 16 17 18 {
			eststo stats_`x': quietly estpost summarize $descriptive if year == (2000+`x'),d
		}

	esttab stats_*  using "$tables/table_descriptive_firmyear_fullperiod.tex", append  ///
		refcat(corporate "\emph{Panel A: Firm characteristics}" total_revenue_th "\emph{Panel B: VAT descriptives}" total_withholding_th "\emph{Panel C: Withholding}"  ///
		positive_balance_panel "\emph{Panel D: Unrefunded credit}", nolabel) /// 
		cells("mean(fmt(%12.0fc))" "sd(fmt(%12.0fc) par)")  ///
		nonum noobs nomtitle  collabels(none)  ///
		label f booktabs gap 
		
		
		foreach x of numlist 15 16 17 18 {
			eststo stats_`x'_n: quietly estpost summarize $descr_n if year == (2000+`x'),d
		}	
		
	esttab stats_*_n using "$tables/table_descriptive_firmyear_fullperiod.tex", append ///
			cells("count(fmt(%12.0fc)) ") label booktabs nonum noobs nomtitle  collabels(none) f  postfoot(\bottomrule) ///
			coeflabels(unit "Number of firms" retenido_tarjetas_n "Firms reporting digital payment witholding")		
restore 


* ========================== TABLE 2 ========================== 
eststo drop *
preserve
	gcollapse (sum) total_revenue_th taxable_sales_th  gross_liability_th credits_th withholding_cards_th ///
			  total_withholding_th endyear_balance change_balance_year, by(id year)
	
	foreach var of varlist taxable_sales_th endyear_balance change_balance_year {
		sort year `var'
		gegen total_aux = total(`var'), by(year)
		by year: gen cumul_aux = sum(`var')
		gen cumul_share_aux = cumul_aux/total_aux
		
		by year: gen d_`var'_50 = cumul_share_aux >= 0.5
		by year: gen d_`var'_80 = cumul_share_aux >= 0.2
		
		drop total_aux cumul_aux cumul_share_aux
	}

	cap mat drop table
	quietly {
		forvalues y = 2014/2019 {
			count if year == `y' & d_taxable_sales_th_50 == 1 
			loc N1 = `r(N)'
			count if year == `y' & d_taxable_sales_th_80 == 1
			loc N2 = `r(N)'
			count if year == `y' & d_endyear_balance_50 == 1 
			loc N3 = `r(N)'
			count if year == `y' & d_endyear_balance_80 == 1
			loc N4 = `r(N)'
			count if year == `y' & d_change_balance_year_50 == 1 
			loc N5 = `r(N)'
			count if year == `y' & d_change_balance_year_80 == 1
			loc N6 = `r(N)'
			
			mat table =  (nullmat(table) \ `N1', `N2', `N3', `N4', `N5', `N6')
		}
	}
	
	frmttable using "$tables/table_shares_top", replace statmat(table) tex /// 
	ctitle( "","{\textbf{Taxable Sales}}", " ","{\textbf{Stock unrefunded credits}} ",  "", "{\textbf{Flow unrefunded credits}}", "" \ ///
	"", "Top 50\%", "Top 80\%", "Top 50\%", "Top 80\%", "Top 50\%", "Top 80\%") ///
	rtitles("2014" \"2015"\ "2016"\"2017"\ "2018"\ "2019")  ///
	nocenter fr multicol(1,2,2;1,4,2; 1,6,2) sd(0) 
restore 


* ========================== FIGURE 2 ========================== 
preserve
	gcollapse (sum) unrefunded_balance_prev_th taxable_sales_th net_liability_th , ///
			by(month)
	
	tsset month
	
	gen cumsum = sum(net_liability_th)
	gen moving_sum = cumsum - L12.cumsum
	
	gen saldo_anterior_mil = unrefunded_balance_prev_th/1000
	gen ratio_bal_liab  = unrefunded_balance_prev_th/moving_sum
	
	format month %tm
	
	twoway (scatter saldo_anterior_mil month , c(l) mcolor(dknavy) lc(dknavy)) ///
	(scatter ratio_bal_liab month , c(l) mcolor(none) lc(none) yaxis(2)), ///
	tline(2014m1 2017m1, lp(dash) lw(thin)) ytitle("Acummulated unrefunded credits (L Million)", axis(1) c(dknavy)) ///
	 ytitle("Accumulated credits as % of VAT liability", axis(2) c(dkorange)) ylab(, labc(dkorange) axis(2))  xtitle("Month")  ///
	 legend(off) tlab(2011m1(12)2018m12, labs(small)) $graphopt
	graph export "$figures/accumulated_balance_0.pdf", replace
	
	twoway (scatter saldo_anterior_mil month , c(l) mcolor(dknavy) lc(dknavy)) ///
	(scatter ratio_bal_liab month , c(l) mcolor(dkorange) lc(dkorange) yaxis(2)), ///
	tline(2014m1 2017m1, lp(dash) lw(thin)) ytitle("Acummulated unrefunded credits (L Million)", axis(1) c(dknavy)) ///
	 ytitle("Accumulated credits as % of VAT liability", axis(2) c(dkorange)) ylab(, labc(dkorange) axis(2)) xtitle("Month") ///
	 legend(off) tlab(2011m1(12)2018m12, labs(small)) $graphopt
	graph export "$figures/accumulated_balance.pdf", replace
restore



* ========================== FIGURE A1 ========================== 
preserve
	gcollapse (sum) taxable_sales_th exempted_sales_th exports_th taxable_purchases_th exempted_purchases_th imports_th, by(year)

	graph bar taxable_sales_th exempted_sales_th exports_th if year > 2011, nofill over(year) stack percent $graphopt ///
          bar(1, color(dknavy)) bar(2, color(gray)) bar(3, color(dkorange)) blabel(bar, color(white) position(center) format(%4.1f) gap(0.5) size(3)) b1title(Year) ///
	      ytitle("Percentage") ylabel(0 (25) 100) legend(row(1) label(1 "Taxable") label(2 "Exempt") label(3 "Exports")) yscale(titlegap(3))        
		  graph export "$figures/composition_sales.pdf", replace
		  
	graph bar taxable_purchases_th exempted_purchases_th imports_th if year > 2011, nofill over(year) stack percent $graphopt ///
          bar(1, color(dknavy)) bar(2, color(gray)) bar(3, color(dkorange)) blabel(bar, color(white) position(center) format(%4.1f) gap(0.5) size(3)) b1title(Year) ///
	      ytitle("Percentage") ylabel(0 (25) 100) legend(row(1) label(1 "Taxable") label(2 "Exempt") label(3 "Imports")) yscale(titlegap(3))        
		  graph export "$figures/composition_purchases.pdf", replace	  
restore


* ========================== FIGURE A2 ========================== 

** Histogram and quartile of net VAT liability to gross VAT liability ratio
preserve
	gcollapse (sum) net_liability_th gross_liability_th credits_th, by(id year)
		
	gen net_share = net_liability_th/gross_liability_th
	gen net_below = net_share <= 0.5
	
	twoway (histogram net_share if year == 2016 & net_share >-1 , frac color(dknavy%80)),  ///
			xtitle("Net VAT liability as % of gross liability") xline(0 0.5, lp(dot) lw(thin)) ///
			legend(off) xlab(-1(0.2)1) ylab(0(0.1)0.3) $graphopt
			graph export "$figures/histo_share.pdf", replace	
			
	summ net_below if year == 2016
	local share: di %3.1f 100*r(mean)
	
	twoway (histogram net_share if year == 2016 & net_share >-1 , frac color(dknavy%95)),  ///
		    xtitle("Net VAT liability as % of gross liability") xline(0 0.5, lp(dot) lw(thin)) ///
			legend(off) xlab(-1(0.2)1) ylab(0(0.1)0.3) xline(-.27, lw(88) lc(dkorange%10)) ///
			text(.25 -.6 "Withhold too much - excess credit", size(small)) ///
			text(.23 -.6 "`share'% of firms", size(small)) $graphopt
			graph export "$figures/histo_share_slides1.pdf", replace	
	
	keep id year net_share
	reshape wide net_share, i(id) j(year)
	
	keep if net_share2015 != .
	xtile quantiles = net_share2015, n(50)
	
	collapse (p50) median = net_share2016 median_2015 = net_share2015 (p25) p25 = net_share2016 ///
	         (p75) p75 = net_share2016 (count) number = id, by(quantiles)

	twoway (rcap p25 p75 median_2015) (scatter median median_2015)  if median_2015 > 0, ///
			xtitle("Net VAT liability as % of gross liability - 2015") ///
			ytitle("Net VAT liability as % of gross liability - 2016") legend(off) $graphopt
			graph export "$figures/scatter_share_intq.pdf", replace
restore


** Box graph of net VAT liability to gross VAT liability ratio across sectors
preserve
	gcollapse (sum) net_liability_th gross_liability_th credits_th, by(id year)
	
	merge m:1 id using  "$databases/Firm_traits.dta"
	drop if _merge == 2
	drop _merge
	
	gen net_share = net_liability_th/gross_liability_th
	
	graph box net_share if net_share > -1 & year == 2016, over(activity_sector, sort(1) label(labsize(small) angle(90))) ///
		  nooutsides alsize(0) ytitle("Net VAT liability as % of gross") $graphopt note("")
		  graph export "$figures/box_share_sectors.pdf", replace
restore

 
 
* ========================== FIGURE 3 ========================== 

keep if inlist(year, 2016,2019)
	
gcollapse (sum) total_revenue_th taxable_sales_th taxable_purchases_th gross_liability_th net_liability_th credits_th total_withholding_th withholding_cards_th withholding_govt_th ///
withholding_large_th total_anticipated_th exports_th (max) change_balance_year endyear_balance dummy_sell_oce dummy_buy_oce, ///
		by(id year)

merge m:1 id using  "$databases/Firm_traits.dta"
drop if _merge == 2
drop _merge

gen value_added = (taxable_sales_th - taxable_purchases_th)

gen net_share = net_liability_th/gross_liability_th
gen credit_more = (credits_th > gross_liability_th)
foreach var of varlist endyear_balance total_withholding_th withholding_cards_th withholding_govt_th withholding_large_th ///
		total_anticipated_th exports_th  {
	gen `var'_d = (`var' > 0 & `var' != .)
	replace `var'_d = . if (`var' == .)
}

gen ratio = endyear_balance/total_revenue_th
gen top_balance = ratio >= 0.01 & ratio != .
replace top_balance = . if (top_balance == 0 & endyear_balance_d == 1)

tab activity_sector, gen(sector_)

gen log_rev = log(0.001 + total_revenue_th)
gen log_bal = log(0.001 + endyear_balance)
gen log_value_added = log(0.001 + value_added)


recode tipo (2 = 0), gen(corporation)
recode size (3 = 0) (2 = 1), gen(medium_large)

lab var log_value_added			"Log value added"
lab var log_rev 				"Log yearly revenue"
lab var withholding_cards_th_d 	"By digital payment providers"
lab var withholding_govt_th_d  	"By the government"
lab var withholding_large_th_d 	"By large firms"
lab var exports_th_d			"Exporter"
lab var corporation				"Corporation"
lab var medium_large			"Medium or large taxpayer"
lab var risk_score				"Risk score"	
	 
	eststo drop *
	reg endyear_balance_d exports_th_d withholding_cards_th_d withholding_govt_th_d withholding_large_th_d i.risk_score ib2.activity_sector ///
						 log_rev log_value_added corporation medium_large if year == 2016, robust
	est store model2016_a
	coefplot model2016_a, base omitted drop(_cons log_rev corporation medium_large log_value_added) $graphopt xline(0, lcolor(black) lp(dash)) ///
		     mcolor(blue%70) ciopts(lcolor(blue*.3) recast(rcap)) legend(off) grid(none) label xlabel(-.2(.1).2) 					   		   ///
			 headings(withholding_cards_th_d = "{bf}Any Withholding" 1.risk_score = "{bf}Risk Score" 1.activity_sector = "{bf}Economic Sectors") 
	graph export "$figures/coefplot_reg_determinants2.pdf", replace	
