/*=============================================================================
Name: 		 4a_PrepareBalancedDefinition.do

Description: This do-file creates identify samples according to different levels 
			 of balancedness and periods.

Input: 	     ISV_panel_vars.dta
			 ISRPN_workingdatabase.dta
			 ISRPJ_workingdatabase.dta

Output: 	 panel_definitions_database.dta
==============================================================================*/


use if year >= 2014  using "$databases/ISV_panel_vars.dta", clear
*sample 5
************* 1. Monthly balancedness ******************************
egen anymonth1 = tag(id month)

sort id
gegen monthcount_2014_2018 =total(anymonth1) if inrange(year,2014,2018), by(id) 
gegen monthcount_2014_2019 =total(anymonth1) if inrange(year,2014,2019), by(id) 
gegen monthcount_2015_2018 =total(anymonth1) if inrange(year,2015,2018), by(id) 
gegen monthcount_2015_2019 =total(anymonth1) if inrange(year,2015,2019), by(id) 


************* 2. Quarterly balancedness ******************************
*--quarter--*
**appear at least once in one quarter***

gen quarter = qofd(date)

sort id
egen anyquarter1 =tag(id quarter)
gegen anyquarter =total(anyquarter1), by(id)

gegen quartercount_2014_2018 =total(anyquarter1) if inrange(year,2014,2018), by(id) 
gegen quartercount_2014_2019 =total(anyquarter1) if inrange(year,2014,2019), by(id)
gegen quartercount_2015_2018 =total(anyquarter1) if inrange(year,2015,2018), by(id) 
gegen quartercount_2015_2019 =total(anyquarter1) if inrange(year,2015,2019), by(id) 


************* 3. Bring Income Tax data, so collapse at yearly level balancedness ******************************
gcollapse (first) *count* , by(id year)

merge 1:1 id year using "$databases/ISRPN_workingdatabase.dta",  keepusing(total_gross_revenue_mil ) gen(mergePN)
drop if mergePN == 2
merge 1:1 id year using  "$databases/ISRPJ_workingdatabase.dta",  keepusing(total_gross_revenue_mil) gen(mergePJ) replace update
drop if mergePJ == 2
drop mergePN  mergePJ
	
gen file_ISR = (total_gross_revenue_mil != .)
gegen ISRcount_2014_2018 =total(file_ISR) if inrange(year,2014,2018), by(id) 
gegen ISRcount_2014_2019 =total(file_ISR) if inrange(year,2014,2019), by(id) 
gegen ISRcount_2015_2018 =total(file_ISR) if inrange(year,2015,2018), by(id) 
gegen ISRcount_2015_2019 =total(file_ISR) if inrange(year,2015,2019), by(id) 


*Balance variables
gen balanced_quarter_1418 = quartercount_2014_2018==20 & ISRcount_2014_2018 == 5 & inrange(year,2014,2018)
gen balanced_quarter_1419 = quartercount_2014_2019==24 & ISRcount_2014_2019 == 6 & inrange(year,2014,2019) 
gen balanced_quarter_1518 = quartercount_2015_2018==16 & ISRcount_2015_2018 == 4 & inrange(year,2015,2018) 
gen balanced_quarter_1519 = quartercount_2015_2019==20 & ISRcount_2015_2019 == 5 & inrange(year,2015,2019) 

gen balanced_month_1418 = (monthcount_2014_2018 == 60 & ISRcount_2014_2018 == 5 & inrange(year,2014,2018)) 
gen balanced_month_1419 = (monthcount_2014_2019 == 72 & ISRcount_2014_2019 == 6 & inrange(year,2014,2019)) 
gen balanced_month_1518 = (monthcount_2015_2018 == 48 & ISRcount_2015_2018 == 4 & inrange(year,2015,2018)) 
gen balanced_month_1519 = (monthcount_2015_2019 == 60 & ISRcount_2015_2019 == 5 & inrange(year,2015,2019)) 


gcollapse (max) balanced* , by(id)


***Generating descriptive stats of number observations in each balanced panel definition
preserve
	gcollapse (sum) balanced*
		
	mkmat *, mat(stats)
restore

mat stats_panels = stats'
frmttable using "$tables/table_stats_panels.tex", replace statmat(stats_panels) tex fr ///
	ctitle( "" , "Number of firms" ) ///
	rtitles("Quarterly 2014 - 2018" \ "Quarterly 2014 - 2019" \ "Quarterly 2015 - 2018" \ "Quarterly 2015 - 2019" \ ///
			"Monthly 2014 - 2018" \ "Monthly 2014 - 2019" \ "Monthly 2015 - 2018" \ "Monthly 2015 - 2019") ///
		sfmt(fc) sdec(0)
		

save "$databases/panel_definitions_database.dta", replace				
