/*=============================================================================
Name: 		 4b_PreparePanelReform_treat.do

Description: This do-file identify different treatment and control groups.

Input: 	     ISV_panel_vars.dta
			 panel_definitions_database.dta

Output: 	 firmlevel_TreatStatus.dta
==============================================================================*/

/*--Open data base---------------------------------------------------------*/
use if year >= 2014  using "$databases/ISV_panel_vars.dta", clear

merge m:1 id using "$databases/panel_definitions_database.dta"
drop if _merge == 2
drop _merge

keep if year == 2016
keep id year month withholding_cards_th withholding_govt_th withholding_large_th total_withholding_th ///
	 withheld_any dummy_with_cards taxable_sales_th gross_liability_th balanced*

**Collapse database at firm level to assess average usage across all months in 2016
gcollapse (sum) withholding_cards_th withholding_govt_th withholding_large_th total_withholding_th gross_liability_th ///
	      dummy_with_cards withheld_any (mean) taxable_sales_th (first) balanced*  , by(id)
		  
		  * Firms with at least one DCC withholding during the year are set to 1
		  replace dummy_with_cards = 1 if dummy_with_cards != 0 
		  
		  * Firms with at least one type of withholding during the year are set to 1
		  replace withheld_any = 1 if withheld_any != 0
		  
		  * DCC witwholding to gross liability ratio
		  gen share_with = withholding_cards_th/gross_liability_th					
		  gen withheld_dummy = (share_with > 0 & !mi(share_with))
		  gen share_tot_with = total_withholding_th/gross_liability_th

** T&C definition	
	foreach var of varlist balanced_quarter_1418 balanced_quarter_1419 balanced_quarter_1518 balanced_quarter_1519 ///
					balanced_month_1418 balanced_month_1419 balanced_month_1518 balanced_month_1519 {
						
					
		summ share_with if share_with > 0 & !mi(share_with) & `var' == 1, d
		loc with_p25 = `r(p25)'
		loc with_p50 = `r(p50)'
		loc with_p75 = `r(p75)'
		summ share_tot_with if share_tot_with > 0 & !mi(share_tot_with) & `var' == 1, d
		loc totwith_p25 = `r(p25)'
		loc totwith_p50 = `r(p50)'
		loc totwith_p75 = `r(p75)'
		
		
		* 0. Baseline T&C: [DCC > p75 |DCC=1] (T) vs [DCC < p25 |DCC=1] (C)
		gen treat0_`var' = .
		replace treat0_`var' = 1 if (share_with >= `with_p75' & !mi(share_with) & `var' == 1)
		replace treat0_`var' = 0 if (share_with <= `with_p25' & share_with >0 & !mi(share_with) & `var' == 1)	
		lab var treat0_`var' "T (DCC > p75), C (DCC < p25)"
		
		
		* 1. First alternative for T&C: [DCC >= p50|DCC=1] (T) vs [DCC < p50|DCC=1] (C)
		gen treat1_`var' = .
		replace treat1_`var' = 1 if (share_with >= `with_p50' & !mi(share_with) & `var' == 1)
		replace treat1_`var' = 0 if (share_with < `with_p50' & share_with >0 & !mi(share_with) & `var' == 1)	
		lab var treat1_`var' "T (DCC >= p50), C (DCC < p50)"
		
		
		* 2. Second alternative for T&C: [DCC >= 1|Any withholding=1] (T) vs [DCC=0|Any withholding=1] (C)
		gen treat2_`var' = .
		replace treat2_`var' = 1 if (withheld_dummy == 1 & `var' == 1)
		replace treat2_`var' = 0 if (withheld_any == 1 & withheld_dummy == 0 & `var' == 1)
		lab var treat2_`var' "T (DCC > 0), C (Any with > 0)"
		
		
		* 3. Third alternative for T&C: [DCC=1|Any withholding=1] (T) vs [DCC=0|Any withholding=0] (C)
		gen treat3_`var' = .
		replace treat3_`var' = 1 if (withheld_dummy == 1 & `var' == 1)
		replace treat3_`var' = 0 if (withheld_any == 0 & withheld_dummy == 0 & `var' == 1)
		lab var treat3_`var' "T (DCC > 0), C (Any with = 0)"
		
		* 4. Fourth alternative for T&C: [DCC > p75 |DCC=1] (T) vs [ALL WITH=0> p75 |DCC=0] (C)
		gen treat4_`var' = .
		replace treat4_`var' = 1 if (share_with >= `with_p75' & !mi(share_with) & `var' == 1)
		replace treat4_`var' = 0 if (share_tot_with >= `totwith_p75' & !mi(share_tot_with) & withholding_cards_th == 0 & `var' == 1)
		lab var treat4_`var' "T (DCC > p75), C (Any with > p75)"
		
	}

keep id balanced_* treat*
save "$databases/firmlevel_TreatStatus.dta", replace


