/*=============================================================================
Name: 		 4d_Prepare_Sales_Shares.do

Description: This do-file creates variables with the share of monthly/quarterly
			 sales in 2016, the year before the reform. These shares are then used 
			 for normalization of outcomes. 

Input: 	     ISV_panel_vars.dta
			 
Output: 	 shares_quarter_2016sales.dta
			 shares_month_2016sales.dta
==============================================================================*/


* Loading VAT records for 2016 only
	use if year == 2016 using "$databases/ISV_panel_vars.dta", clear
	
	gen quarter_id = quarter(dofm(month))
	gen month_id   = month(dofm(month))
	
	
* Merge with true value of income in 2016	
	merge m:1 id year using "$databases/Annual_sales.dta", keepusing(final_revenue_mil max_income_tax)
	drop if _merge == 2
	drop _merge
	
	gen final_revenue_th = final_revenue_mil * 1000	
	
	
* Building quarterly shares
	preserve		
		gcollapse (first) year final_revenue_th max_income_tax (sum) total_revenue_th, by(id quarter_id)
				  
		bys id: egen total = total(total_revenue_th)
		bys id: gen share_quarter = total_revenue_th / total
		bys id: gen n_quarter = _N
		bys id: egen max_share = max(share_quarter)
		
		* We define a share = 0.25 for firms reporting all their sales in only one specific quarter
		replace share_quarter = 1/4 if (n_quarter == 4 & max_share == 1) | (max_income_tax == 1 & n_quarter == 4 & total == 0)
		
		keep id quarter_id year share_quarter
		save "$databases/shares_quarter_2016sales.dta", replace
	restore
	

* Building monthly shares
	preserve
		gcollapse (first) year final_revenue_th max_income_tax (sum) total_revenue_th, by(id month_id)
		
		bys id: egen total = total(total_revenue_th)
		bys id: gen share_month = total_revenue_th / total
		bys id: gen n_month = _N
		bys id: egen max_share = max(share_month)
		
		* We define a share = 1/12 for firms reporting all their sales in only one specific month
		replace share_month = 1/12 if (n_month == 12 & max_share == 1) | (max_income_tax == 1 & n_month == 12 & total == 0)

		keep id month_id year share_month
		save "$databases/shares_month_2016sales.dta", replace
	restore
	