/*=============================================================================
Name: 		 5a_Descriptives_Reform_$figures.do

Description: This do file produces figures 3, A4, A5, A6, A7, A8, A9, A10, A15, 
			 and A16.

Input: 	     ISV_panel_vars.dta
			 firmlevel_TreatStatus.dta
			 
Output: 	 change_share_withheld_FULL.pdf
			 change_retention_all_FULL.pdf
			 withhold_amounts_compare.pdf
			 cdf_share_withheld_fullperiod.pdf
			 change_share_withheld_all.pdf
			 density_with.pdf
			 density_with_usage.pdf
			 histo_sharewith_tc.pdf
			 share_claiming.pdf
			 firms_entry_atc.pdf
			 firms_claim_atc.pdf
			 var_dcc_usage_control.pdf
			 var_dcc_usage_treatment.pdf
			 intensity.pdf
			 vat_change.pdf
			 vat_change_firms_withheld.pdf
			 vat_change_firms_withheld_noscale.pdf
			 vat_change_firms_withheld_normalized.pdf
==============================================================================*/


	*--Open data base---------------------------------------------------------*
	use "$databases/ISV_panel_vars.dta", clear
			
	gen quarter = qofd(date)
	format %tq quarter 
	
	*--Combining with treatment and control groups-------------------------------*

	merge m:1 id using "$databases/firmlevel_TreatStatus.dta"
	drop if _merge == 2

	gen firm_not2016 = (_merge == 1)
	drop _merge
	
	
	
* ========================== FIGURE 4a ========================== 
preserve
	keep if (dummy_with_cards == 1 & share_withheld < 2)
	count 
	loc N: di %8.0fc `r(N)'
	
	gcollapse (mean) mean = share_withheld (semean) se = share_withheld, by(month)
	gen ub = mean + 1.96*se
	gen lb = mean - 1.96*se
	format month %tm
	
	twoway (rcap ub lb month, lc(gs8%50)) (scatter mean month, mc(dknavy)), tline(2014m1 2017m1 2017m3, lp(dash) lw(thin))  ///
		legend(off) tlab(2011m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ///
		ttext(.35 2019m1 "N = `N'") xtitle("Month")  $graphopt
	graph export "$figures/change_share_withheld_FULL.pdf", replace
restore	

	
* ========================== FIGURE 4b ========================== 
preserve
	replace dummy_with_cards = . if taxable_sales_th == 0

	count 
	loc N: di %12.0fc `r(N)'
	
	gcollapse (mean) mean = withholding_cards_th (semean) se = withholding_cards_th (sum) dummy_with_cards total_withheld = withholding_cards_th ///
		(mean) share_claimants = dummy_with_cards (count) id, by(month)
	gen ub = mean + 1.96*se
	gen lb = mean - 1.96*se
	format month %tm
	
	twoway (rcap ub lb month, lc(gs8%50) ) (scatter mean month, mc(dknavy)), tline(2014m1 2017m1 2017m3, lp(dash) lw(thin)) ///
			legend(off) tlab(2011m1(12)2019m12) ytitle("Claimed withheld taxes (L1,000s)") xtitle("Month") ttext(7 2019m1 "N = `N'")  $graphopt
	graph export "$figures/change_retention_all_FULL.pdf", replace

	/* 
	twoway (scatter dummy_with_cards month, c(l)), $graphopt tlab(2011m1(12)2019m12) ///
			ytitle("Number filers claiming CDC deduction") tline(2014m1 2017m1 2017m3, lp(dash) lw(thin)) 
			graph export "$figures/number_claiming.pdf", replace 
	
	twoway (scatter id month, c(l)), $graphopt tlab(2011m1(12)2019m12) ///
		   ytitle("Number of ISV filers") tline(2014m1 2017m1 2017m3, lp(dash) lw(thin)) 
		   graph export "$figures/number_filers.pdf", replace 
	
	twoway (scatter id month, c(l)) (scatter dummy_with_cards month, c(l) yaxis(2)), $graphopt  ///
		   tlab(2011m1(12)2019m12) ytitle("Number of ISV filers", axis(1)) ytitle("Number filers claiming DCC deduction", axis(2)) ///
		   tline(2014m1 2017m1 2017m3, lp(dash) lw(thin)) legend(lab(1 "ISV filers (LHS)") lab(2 "Deduction Claimers (RHS)"))
		   graph export "$figures/number_filers_with.pdf", replace 
	
	twoway (scatter total_withheld month, c(l)), $graphopt tlab(2011m1(12)2019m12) ///
			ytitle("Total claimed withholding (L1,000s)") ylab(0(50000)300000) tline(2014m1 2017m1 2017m3, lp(dash) lw(thin)) 
			graph export "$figures/amount_withheld.pdf", replace */
restore



* ========================== FIGURE 5a ========================== 
preserve
	keep if year >= 2015
	
	gcollapse (sum) total_withholding_th withholding_cards_th withholding_govt_th withholding_large_th, by(quarter)
	format quarter %tq

	
// 	twoway (scatter withholding_govt_th quarter, c(l) lc(dkgreen) mc(dkgreen)), ///
// 		   tline(2017q1, lp(dash) lw(thin)) $graphopt ///
// 		   legend(off) ytitle("Claimed withheld taxes (L1,000s)") ///
// 		   ylab(0(200000)800000) ttext(350000 2019q2 "Government", size(small) color(dkgreen)) 
// 		   graph export "$figures/withhold_amounts_compare_0.pdf", replace
	
// 	twoway (scatter withholding_govt_th quarter, c(l) lc(dkgreen) mc(dkgreen)) ///
// 		   (scatter withholding_large_th quarter, c(l) lc(dkorange)  mc(dkorange)), ///
// 		   tline(2017q1, lp(dash) lw(thin)) $graphopt ///
// 		   legend(off) ytitle("Claimed withheld taxes (L1,000s)") ///
// 		   ylab(0(200000)800000) ttext(350000 2019q2 "Government", size(small) color(dkgreen))  ///
// 		   ttext(650000 2019q2 "Large taxpayers", size(small) color(dkorange))
// 	       graph export "$figures/withhold_amounts_compare_1.pdf", replace
		   
	twoway (scatter withholding_govt_th quarter, c(l) lc(dkgreen) mc(dkgreen)) ///
		   (scatter withholding_large_th quarter, c(l) lc(dkorange)  mc(dkorange)) ///
		   (scatter withholding_cards_th  quarter, c(l) lc(dknavy) mc(dknavy) lw(thick)), ///
		   tline(2017q1, lp(dash) lw(thin)) xtitle("Quarter") $graphopt ///
		   legend(off) ytitle("Claimed withheld taxes (L1,000s)") ylab(0(200000)800000, format(%8.0fc)) ///
		   ttext(700000 2015q4 "Digital payments", size(medsmall) color(dknavy)) ///
		   ttext(650000 2019q2 "Large taxpayers", size(medsmall) color(dkorange)) ///
		   ttext(350000 2019q2 "Government", size(medsmall) color(dkgreen)) 
		   graph export "$figures/withhold_amounts_compare.pdf", replace
restore


/**Presentation graphs (NBER - 2017 only)
preserve
	keep if (dummy_with_cards == 1 & share_withheld < 2) & inrange(year, 2014, 2019)
	count 
	loc N: di %8.0fc `r(N)'
	
	gcollapse (mean) mean = share_withheld (semean) se = share_withheld, by(month)
	gen ub = mean + 1.96*se
	gen lb = mean - 1.96*se
	format month %tm
	
	twoway (rcap ub lb month, lc(gs8)) (scatter mean month, mc(dknavy)) if month < tm(2017m1) & month > tm(2014m2), ///
		tline(2017m1 2017m3, lp(dash) lw(thin)) $graphopt ///
		legend(off) tlab(2014m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ylab(0(0.1)0.4)
	graph export "$figures/change_share_withheld_FULL_0_onlysecond.pdf", replace

	twoway (rcap ub lb month, lc(gs8)) (scatter mean month, mc(dknavy)) if  month > tm(2014m2), ///
		tline(2017m1 2017m3, lp(dash) lw(thin)) $graphopt ///
		legend(off) tlab(2014m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ///
		ylab(0(0.1)0.4) ttext(.35 2019m1 "N = `N'")
	graph export "$figures/change_share_withheld_FULL_2_onlysecond_.pdf", replace
restore
*/


* ========================== FIGURE 6 ========================== 
preserve	
	keep if (inrange(month, tm(2013m4), tm(2013m12)) | inrange(month, tm(2015m4), tm(2015m12)) | ///
	inrange(month, tm(2017m4), tm(2017m12)))
	gen withheld = (withholding_cards_th > 0 & withholding_cards_th != .)
	gcollapse (sum) withholding_cards_th gross_liability_th (mean) taxable_sales_th , by(id year)
	
	gen share_with = withholding_cards_th/gross_liability_th
		
	cdfplot share_with if inrange(share_with,0.0000001, 1) [w = gross_liability_th] , by(year)  ///
		graphregion(fcolor(white) lcolor(gs16)) xline(0.1 0.5 1, lp(dot)) $graphopt ///
		opt1(lc(dkorange dknavy gs8)) xlab(0 .1 .3 .5 .6 .8 1) legend(off) ///
		text(.92 .12 "2017", placement(ne) color(gs8) size(medsmall))  text(.9 .3 "2015", placement(ne) color(dknavy) size(medsmall)) ///
		text(.7 .25 "2013", placement(ne) color(dkorange) size(medsmall)) xtitle("Share taxes withheld by Digital Payment Providers")
	graph export "$figures/cdf_share_withheld_fullperiod.pdf", replace
restore


* ========================== FIGURE A3 ========================== 
preserve
	keep if (share_withheld < 2)
	count 
	loc N: di %8.0fc `r(N)'
	
	gcollapse (mean) mean = share_withheld (semean) se = share_withheld, by(month)
	gen ub = mean + 1.96*se
	gen lb = mean - 1.96*se
	format month %tm
	
	twoway (rcap ub lb month, lc(gs8)) (scatter mean month, mc(dknavy)), tline(2014m1 2017m1 2017m3, lp(dash) lw(thin))  ///
		legend(off) tlab(2011m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ///
		ttext(.35 2019m1 "N = `N'") $graphopt
	graph export "$figures/change_share_withheld_all.pdf", replace
restore


/* FIGURE A3 BUT DYNAMIC (for presentations only)
preserve
	keep if (dummy_with_cards == 1 & share_withheld < 2)
	count 
	loc N: di %8.0fc `r(N)'
	
	gcollapse (mean) mean = share_withheld (semean) se = share_withheld, by(month)
	gen ub = mean + 1.96*se
	gen lb = mean - 1.96*se
	format month %tm
	
	twoway (rcap ub lb month, lc(gs8)) (scatter mean month, mc(dknavy)) if month < tm(2014m1), tline(2014m1 2017m1 2017m3, lp(dash) lw(thin))  ///
		legend(off) tlab(2011m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ylab(0(0.1)0.4) $graphopt
	graph export "$figures/change_share_withheld_FULL_0.pdf", replace
		
	twoway (rcap ub lb month, lc(gs8)) (scatter mean month, mc(dknavy)) if month < tm(2017m1), tline(2014m1 2017m1 2017m3, lp(dash) lw(thin))  ///
		legend(off) tlab(2011m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ylab(0(0.1)0.4) $graphopt
	graph export "$figures/change_share_withheld_FULL_1.pdf", replace
	
	twoway (rcap ub lb month, lc(gs8)) (scatter mean month, mc(dknavy)), tline(2014m1 2017m1 2017m3, lp(dash) lw(thin))  ///
		legend(off) tlab(2011m1(12)2019m12) ytitle("Claimed withheld taxes as % tax") ///
		ylab(0(0.1)0.4) ttext(.35 2019m1 "N = `N'") $graphopt
	graph export "$figures/change_share_withheld_FULL_2.pdf", replace
restore
*/
	
	
* ========================== FIGURE A4 ========================== 
preserve
	keep if year == 2016
	
	gcollapse (sum) taxable_sales_th (first) dummy_with_cards balanced_${vat_freq}_${vat_since}${vat_to} treat0_${panel_vat}, by(id)

	gen log_sales = log(taxable_sales_th)
	
	gen group = .
	replace group = 1 if dummy_with_cards == 0
	replace group = 2 if dummy_with_cards == 1 & treat0_${panel_vat} == 0
	replace group = 3 if dummy_with_cards == 1 & treat0_${panel_vat} == 1 
	replace group = 4 if dummy_with_cards == 1 & treat0_${panel_vat} == .
	label var group "Withholding intensity in 2016"
	label define group 1"No withholding firm" 2"Low withholding firm" 3"High withholding firm" 4"Intermediary withholding firm", replace
	label val group group
	
	twoway (kdensity log_sales if group == 1 & log_sales>1, lw(thick) lc(gs8)) ///
		   (kdensity log_sales if inrange(group,2,4) & log_sales>1, lw(thick) lc(dknavy)),  ///
			legend(off) $graphopt ///
			text(.21 12 "Digital provider withholding", size(small) color(dknavy)) ///
			text(.21 2.2  "No DP withholding", size(small) color(gs8)) ///
			xtitle("Log taxable sales") ytitle("Density")
	graph export "$figures/density_with.pdf", replace
	
	twoway (kdensity log_sales if group == 1 & log_sales>1, lw(thick)  lc(gs8)) ///
			(kdensity log_sales if group == 3 & log_sales>1, lw(thick) lc(dknavy)) ///
			(kdensity log_sales if group == 2 & log_sales>1, lw(thick) lc(dkorange)), ///
			xtitle("Log taxable sales") ytitle("Density") legend(off) $graphopt ///
 			text(.23 2.2  "No withholding", size(small) color(gs8)) ///
			text(.25 9.3 "High usage", size(small) color(dknavy)) ///
			text(.21 11  "Low usage", size(small) color(dkorange))
	graph export "$figures/density_with_usage.pdf", replace
restore	
	
	
* ========================== FIGURE A5 ========================== 
preserve
	keep if year >= 2014 
	summ share_withheld if share_withheld > 0 & !mi(share_withheld) & balanced_${vat_freq}_${vat_since}${vat_to} == 1, d
	histogram share_withheld if (share_withheld > 0 & !mi(share_withheld) & share_withheld < 1 & balanced_${vat_freq}_${vat_since}${vat_to} == 1), ///
			  xline(`r(p25)' `r(p75)', lp(dash) lc(red) lw(medthick))  lcolor(dknavy%70) fcolor(dknavy%70) text(.11 .22 "{&rarr}", color(red)) ///
			  bin(100) xtitle("DPP withholding as % of gross liability") frac text(.105 .23 "Treatment", size(small) color(red)) $graphopt ylabel(, angle(0))
	graph export "$figures/histo_sharewith_tc.pdf", replace
restore



* ========================== FIGURE A6a ========================== 
preserve
	replace dummy_with_cards = . if taxable_sales_th == 0

	gcollapse (mean) mean = withholding_cards_th (semean) se = withholding_cards_th (sum) dummy_with_cards total_withheld = withholding_cards_th ///
		(mean) share_claimants = dummy_with_cards (count) id	, by(month)
	gen ub = mean + 1.96*se
	gen lb = mean - 1.96*se
	format month %tm
	
	twoway (scatter share_claimants month, c(l)), $graphopt tlab(2011m1(12)2019m12, labsize(small)) ///
		    ytitle("Share filers claiming CDC deduction") tline(2014m1 2017m1, lp(dash) lw(thin)) 
			graph export "$figures/share_claiming.pdf", replace
restore



* ========================== FIGURE A6b ========================== 
preserve
	keep if dummy_with_cards == 1
	
	sort id month 
	bys id: egen firstperiod = min(month)

	gen entry = 0 
	replace entry = 1 if month == firstperiod
	
	gcollapse (sum) entry dummy_with_cards, by(month)
	drop if month < tm(2015m1)
	
	twoway (scatter entry month, c(l)), tlab(2015m1(12)2019m12, labsize(small)) $graphopt ///
		   tline(2017m1, lp(dash) lw(thin)) ylab(0(25)200) legend(off) ///
		   ytitle("Number of new firms claiming digital payment withholding", size(small)) xscale(titlegap(3)) yscale(titlegap(3))
		   graph export "$figures/firms_entry_atc.pdf", replace
		   
	twoway (scatter dummy_with_cards month, c(l)), tlab(2015m1(12)2019m12, labsize(small)) $graphopt ///
		   tline(2017m1, lp(dash) lw(thin))  ylab(3000(500)5000)  legend(off) ///
		   ytitle("Number of firms claiming digital payment withholding", size(small)) xscale(titlegap(3)) yscale(titlegap(3))
	graph export "$figures/firms_claim_atc.pdf", replace
restore




/*******************************************************************************	
 Distribution of changes in DCC usage after the reform
*******************************************************************************/

* Extrapolation of sales with debit and credit cards (we assume a flat VAT rate of 15, before 2017 = 0.15 * 0.5; after 2017 = 0.15 * 0.1)
	gen trans_value = .
	replace trans_value = withholding_cards_th / 0.075 if dummy_with_cards == 1 & (year >= 2014  & year < 2017)
	replace trans_value = withholding_cards_th / 0.015 if dummy_with_cards == 1 & (year >= 2017)
	winsor2 trans_value, cut(0 99)

preserve
	gcollapse (sum) withholding_cards_th gross_liability_th trans_value_w total_revenue_th (first) treat0_balanced_quarter_1518, by(id year)
	gen share_dcc = trans_value_w / total_revenue_th
	replace share_dcc = cond(share_dcc>1, 1, share_dcc)
	
	   /*
	   * DCC sales / Total sales ratio for T&C groups in 2016
	   tabstat share_dcc if year == 2016, s(mean) by( treat0_balanced_quarter_1518)
		Summary for variables: share_dcc
		Group variable: treat0_balanced_quarter_1518 ((first) T (DCC > p75), C (DCC < p25))

		treat0_balanced_quarter_1518 |      Mean
		-----------------------------+----------
								   0 |  .0204832
								   1 |  .6466393
		-----------------------------+----------
							   Total |  .3335613
		----------------------------------------
	   */
	   
	   
	   * Interannual variation in the DCC intensive margin
	   bys id: gen yr_2016_dcc = share_dcc if year == 2016
	   bys id: egen share_2016 = max(yr_2016_dcc)
	   gen var_share = share_dcc - share_2016
		
		count if var_share >= 0.63 & treat0_balanced_quarter_1518 == 0 & year == 2017
		loc n_aftera = `r(N)'
		count if treat0_balanced_quarter_1518 == 0 & year == 2017
		loc n_17a = `r(N)'
		loc share_change: dis %4.0fc (`n_aftera' / `n_17a')*100

		twoway (hist var_share if (year == 2017 & treat0_balanced_quarter_1518 == 0), lcolor(dknavy%70) fcolor(dknavy%70) percent bin(30)) 						///
			   (hist var_share if (year == 2018 & treat0_balanced_quarter_1518 == 0), lcolor(dknavy) fcolor(none) percent bin(30)), 								///
			   $graphopt legend(row(2) order(1 "2017 - 2016" 2 "2018 - 2016") ring(0) pos(1) size(small)) xline(0, lcolor(red) lp(dash)) ylabel(0(10)60, angle(0)) ///
			   xtitle("∆ DCC sales (p.p.)") subtitle("Percentage" "of firms (%)", placement(7) span size(small)) ytitle("") xscale(titlegap(3)) yscale(titlegap(3)) ///
			   xline(0.63, lcolor(gray) lp(dash)) text(35 .50 "`share_change'% of low usage firms" "became high usage" "in 2017", color(gray) size(small))
		graph export "$figures/var_dcc_usage_control.pdf", replace
		
		count if var_share <= -0.63 & treat0_balanced_quarter_1518 == 1 & year == 2017
		loc n_afterb = `r(N)'
		count if treat0_balanced_quarter_1518 == 1 & year == 2017
		loc n_17b = `r(N)'
		loc share_change: dis %4.0fc (`n_afterb' / `n_17b')*100

		twoway (hist var_share if (year == 2017 & treat0_balanced_quarter_1518 == 1 & var_share < 0.05), lcolor(dknavy%70) fcolor(dknavy%70) percent bin(30)) 		 ///
			   (hist var_share if (year == 2018 & treat0_balanced_quarter_1518 == 1 & var_share < 0.05), lcolor(dknavy) fcolor(none) percent bin(30)), 			 ///
			   $graphopt legend(row(2) order(1 "2017 - 2016" 2 "2018 - 2016") ring(0) pos(12) size(small)) xline(0, lcolor(red) lp(dash)) ylabel(0(10)40, angle(0))  ///
			   xtitle("∆ DCC sales (p.p.)")  subtitle("Percentage" "of firms (%)", placement(7) span size(small)) ytitle("") xscale(titlegap(3)) yscale(titlegap(3)) ///
			   xline(-0.63, lcolor(gray) lp(dash)) text(20 -.77 "`share_change'% of high usage firms" "became low usage" "in 2017", color(gray) size(small))  
		graph export "$figures/var_dcc_usage_treatment.pdf", replace	
restore		

preserve
	keep if year >= 2015 & year <= 2018
	keep if treat0_${panel_vat} != .

	gcollapse (sum) trans_value_w total_revenue_th (first) treat0_${panel_vat}, by(id quarter)
	gen share_dcc = trans_value_w / total_revenue_th
	replace share_dcc = cond(share_dcc>1, 1, share_dcc)
	gcollapse (mean) share_dcc (semean) se_share = share_dcc, by(quarter treat0_balanced_quarter_1518)
	
	gen se_low_0  = share_dcc - (1.96*se_share) if treat0_balanced_quarter_1518 == 0
	gen se_high_0 = share_dcc + (1.96*se_share) if treat0_balanced_quarter_1518 == 0
	gen se_low_1  = share_dcc - (1.96*se_share) if treat0_balanced_quarter_1518 == 1
	gen se_high_1 = share_dcc + (1.96*se_share) if treat0_balanced_quarter_1518 == 1
	
	twoway (scatter share_dcc quarter if (quarter >= tq(2015q1) & quarter <= tq(2018q4) & treat0_balanced_quarter_1518 == 0), c(l) mc(orange%80) lc(orange%80) lw(medthin) msize(small)) ///
		   (scatter share_dcc quarter if (quarter >= tq(2015q1) & quarter <= tq(2018q4) & treat0_balanced_quarter_1518 == 1), c(l) mc(dknavy%80) lc(dknavy%80) lw(medthin) msize(small)) ///
		   (rcap se_low_0 se_high_0 quarter if (quarter >= tq(2015q1) & quarter <= tq(2018q4) & treat0_balanced_quarter_1518 == 0), lc(orange%80)) 	/// 
		   (rcap se_low_1 se_high_1 quarter if (quarter >= tq(2015q1) & quarter <= tq(2018q4) & treat0_balanced_quarter_1518 == 1), lc(dknavy%80)), /// 
		   $graphopt tline(2017q1, lcolor(gray%80) lp(--)) legend(off) ytitle("") subtitle("Average" "(%)", placement(7) span size(small))   		///
		   text(.4 229 "Reform" "Jan'17", size(small) color(gray%80)) text(.65 222 "High DCC usage", size(small) color(dknavy%80)) 					///
		   text(.14 222 "Low DCC usage", size(small) color(orange%80)) ylabel(, angle(0)) xtitle("Quarter") xscale(titlegap(3)) 
	graph export "$figures/intensity.pdf", replace
restore


preserve
	egen tax_total  = rowtotal(net_payment_th total_withholding_th total_anticipated_th) 
	replace tax_total = (tax_total* 1000) / 1000000
	gen net_payment = (net_payment_th * 1000) / 1000000
	gcollapse (sum) tax_total net_payment (first) dummy_with_cards treat0_balanced_quarter_1518, by(quarter)
	
	tsset quarter
	keep if quarter >= tq(2015q1) & quarter <= tq(2019q4)
	
	twoway (scatter tax_total quarter   if (quarter >= tq(2015q1) & quarter <= tq(2019q4)), c(l) lcolor(dkorange%60) lw(thin) mcolor(dkorange%60) msymbol(D)) ///
		   (scatter net_payment quarter if (quarter >= tq(2015q1) & quarter <= tq(2019q4)), c(l) lcolor(dkgreen%60) lw(thin) mcolor(dkgreen%60)), ///
		   $graphopt tline(2017q1, lcolor(gray) lp(--)) subtitle("Millions" "Lempiras", placement(7) span size(small)) ///
		   xtitle("") ylabel(0(1000)6200, format(%12.0fc) labsize(small) angle(0)) xlabel(#10, labsize(small)) legend(off) ///
		   text(5500 232 "Total VAT payments", color(dkorange%60)) text(3500 232 "Net VAT payments", color(dkgreen%60))		   
	graph export "$figures/vat_change.pdf", replace
restore
	
preserve
	keep if balanced_quarter_1519 == 1
	egen tax_total  = rowtotal(net_payment_th total_withholding_th total_anticipated_th) 
	replace tax_total = (tax_total* 1000) / 1000000
	gcollapse (sum) tax_total, by(quarter dummy_with_cards)
	drop if mi(dummy_with_cards)
	reshape wide tax_total, i(quarter) j(dummy_with_cards)
	tempfile dcc_with_q
	save `dcc_with_q'
restore

preserve
	keep if treat0_balanced_quarter_1518 == 1
	egen tax_total  = rowtotal(net_payment_th total_withholding_th total_anticipated_th) 
	replace tax_total = (tax_total* 1000) / 1000000
	gcollapse (sum) tax_total, by(quarter)
	
	merge 1:1 quarter using `dcc_with_q', keepusing(tax_total1)
	drop _merge
		   
	* Scale with respect to quarterly average of 2016q4
	egen tax_total_2016  = mean(tax_total)  if quarter >= tq(2016q1) & quarter <= tq(2016q4)
	egen tax_total1_2016 = mean(tax_total1) if quarter >= tq(2016q1) & quarter <= tq(2016q4)

	egen max_tax_16  = max(tax_total_2016)
	egen max_tax1_16 = max(tax_total1_2016)
	
	gen normal_tax_16  = tax_total  / max_tax_16
	gen normal_tax1_16 = tax_total1 / max_tax1_16
	
	* Figures
	twoway (scatter tax_total quarter   if (quarter >= tq(2015q1) & quarter <= tq(2019q4)), c(l) lcolor(dknavy%60) lw(thin) mcolor(dknavy%60) msymbol(D)) ///
		   (scatter tax_total1 quarter if (quarter >= tq(2015q1) & quarter <= tq(2019q4)), c(l) lcolor(blue%50) lw(thin) mcolor(blue%50)), ///
		   $graphopt tline(2017q1, lcolor(gray) lp(--)) subtitle("Millions" "Lempiras", placement(7) span size(small)) ///
		   xtitle("") ylabel(0(1000)6200, format(%12.0fc) labsize(small) angle(0)) xlabel(#10, labsize(small)) legend(off) ///
		   text(2000 232 "Any digital payment (DP) withholding", color(blue%50) size(small)) text(500 232 "High-usage DP", color(dknavy%60))
	graph export "$figures/vat_change_firms_withheld.pdf", replace
	
	twoway (scatter tax_total quarter   if (quarter >= tq(2015q1) & quarter <= tq(2019q4)), c(l) lcolor(dknavy%60) lw(thin) mcolor(dknavy%60) msymbol(D)) ///
		   (scatter tax_total1 quarter if (quarter >= tq(2015q1) & quarter <= tq(2019q4)), c(l) lcolor(blue%50) lw(thin) mcolor(blue%50) yaxis(2)), 	  ///
		   $graphopt tline(2017q1, lcolor(gray) lp(--)) legend(off) xtitle("") xlabel(#10, labsize(small)) 												  ///
		   ytitle("Treated firms (L Million)", axis(1) c(dknavy%70)) ylabel(0(50)300, format(%12.0fc) labsize(small) angle(0) axis(1) labc(dknavy%70)) 	  ///
		   ytitle("All DCC withheld firms (L Million)", axis(2) c(blue%50)) ylabel(0(500)2000, format(%12.0fc) labsize(small) angle(0) axis(2) labc(blue%50))  
	graph export "$figures/vat_change_firms_withheld_noscale.pdf", replace
	
	twoway (scatter normal_tax_16  quarter if quarter >= tq(2015q1) & quarter <= tq(2019q4), c(l) lcolor(dknavy%60) lw(thin) mcolor(dknavy%60) msymbol(D)) ///
		   (scatter normal_tax1_16 quarter if quarter >= tq(2015q1) & quarter <= tq(2019q4), c(l) lcolor(blue%50) lw(thin) mcolor(blue%50)), ///
		   $graphopt tline(2016q4, lcolor(gray) lp(--)) subtitle("VAT payment" "(2016=1)", placement(7) span size(small)) legend(off)        ///
		   xtitle("") ylabel(0(.25)1.75, labsize(small) angle(0)) xlabel(#9, labsize(small)) yscale(titlegap(1)) yline(1, lp(dash) lc(red) lw(vthin)) ///
		   text(1.5 232 "Any digital payment (DP) withholding", size(small) color(blue%50)) text(.5 232 "High-usage DP", color(dknavy%60))		   
	graph export "$figures/vat_change_firms_withheld_normalized.pdf", replace
restore

		