/*=============================================================================
Name: 		 4e_Descriptives_SERaggregates.do

Description: This do file produces Figure A4b. 

Input: 	     Base_Mensual_SER_201101_201912.dta
			 ISV_panel_vars.dta
			 
Output: 	 withholding_isv_ser.pdf
==============================================================================*/

use "$databases/Base_Mensual_SER_201101_201912.dta", clear

keep if month >= tm(2015m1)

gen quarter = qofd(date)
format %tq quarter 

gcollapse (sum) devol_8isv debitofiscal imptopagar, by(quarter)


/*----getting ISV panel vars on withholding-------------------------------*/
preserve
	use "$databases/ISV_panel_vars.dta", clear
	
	keep if inrange(year, 2015,2019)
	
	gen quarter = qofd(date)
	format %tq quarter 

	gcollapse (sum) withholding_cards_th , by(quarter)
	
	tempfile ISVdata
	save "`ISVdata'"
restore 


merge 1:1 quarter using "`ISVdata'"
drop _merge

replace devol_8isv 	 = devol_8isv/1000
replace imptopagar = imptopagar/1000

egen withholding_SER = rowtotal(imptopagar devol_8isv)							
gen ratio = withholding_cards_th/withholding_SER


/*----compare withheld amount claimed in ISV and withheld remitted (BI-SER)--------------------------------------------------*/

twoway (scatter withholding_cards_th quarter, c(l) lc(dknavy) mc(dknavy)) ///
		(scatter withholding_SER quarter, c(l)  lc(dkorange) mc(dkorange)) , ///
		tline(2017q1, lp(dash) lw(thin)) ylab(, format(%12.0fc)) $graphopt ///
		legend(off) ytitle("Withheld taxes (L1,000s)") xtitle("Quarter") ///
		ttext(700000 2019q2 "Payments data", color(dkorange))  ///
		ttext(650000 2019q2 "Firm VAT data",  color(dknavy))
		graph export "$figures/withholding_isv_ser.pdf", replace
		
		