/*==============================================================================
Name: 		 6c_Robustness_ISV_Treat.do

Description: Conducts robustness checks for VAT outcomes changing the baseline 
			 definition of treatment and control groups. Produces figure A17.

Input: 	     ISV_reform_panel_quarter.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 vat_robustness2.tex
			 did3_value_added.pdf
			 did3_tax_total.pdf
			 did3_etr.pdf
			 did3_dummy_unrefunded.pdf
			 did3_unref_balance.pdf
			 did3_revenue.pdf
			 did3_tax_sales.pdf
			 did3_purchases.pdf
			 did3_tax_purchases.pdf
			 did3_exem_purchases.pdf
			 did3_withholding_cards.pdf
			 did3_withholding.pdf
==============================================================================*/


/*******************************************************************************	
 1. Import VAT records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_vat_data

	   
/*******************************************************************************	
 3. $figures 17 with dynamic DiD estimations using different T&C groups
*******************************************************************************/

* $figures comparing compliance effects between baseline and alternative T&C samples 
* Only 2015q1-2018q4, and outcomes winsorized at the 95th fraction of observations, as we do in baseline estimations
		
	cap est drop * 
	foreach var of varlist $var_compliance $var_outcomes {
		
		 local lab: variable label `var'
	
		 forvalues i = 0/3 {
			gen treat = treat`i'_balanced_${vat_freq}_${vat_since}${vat_to} 
			eststo m`i': qui reghdfe `var'_n_`i'_${vat_since}${vat_to}_w95 ib0.treat##ib227.${vat_freq}, a(id quarter#activity_sector#quantile`i'_${vat_freq}_${vat_since}${vat_to}) cluster(id)
			drop treat
		 }
	
		coefplot (m0, keep(1.treat*#*quarter*) baselevels omitted label("Baseline: [DCC>p75|DCC=1] vs [DCC<p25|DCC=1]") ///
				 lw(thin) msymbol(S) mcolor(black) msize(medsmall) ciopts(recast(rcap) lcolor(black*.3))) ///
				 (m1, keep(1.treat*#*quarter*) baselevels omitted label("[DCC>=p50|DCC=1] vs [DCC<p50|DCC=1]") ///
				 lw(thin) msymbol(O) mcolor(blue) msize(medsmall) ciopts(recast(rcap) lcolor(blue*.3)) offset(-0.3)) ///
				 (m2, keep(1.treat*#*quarter*) baselevels omitted label("[DCC=1|Withholding=1] vs [DCC=0|Withholding=1]") ///
				 lw(thin) msymbol(D) mcolor(orange) msize(medsmall) ciopts(recast(rcap) lcolor(orange*.3)) offset(-0.2)) ///
				 (m3, keep(1.treat*#*quarter*) baselevels omitted label("[DCC=1|Withholding=1] vs [DCC=0|Withholding=0]") ///
				 lw(thin) msymbol(T) mcolor(green) msize(medsmall) ciopts(recast(rcap) lcolor(green*.3)) offset(-0.1)), ///
				 yline(0, lc(black) lw(thin)) omitted vertical baselevels nolabels $graphopt ///
				 coeflabel(1.treat#220.quarter = "2015q1" 1.treat#221.quarter = "2015q2" ///
				 1.treat#222.quarter = "2015q3" 1.treat#223.quarter = "2015q4" 1.treat#224.quarter = "2016q1" ///
				 1.treat#225.quarter = "2016q2" 1.treat#226.quarter = "2016q3" 1.treat#227.quarter = "2016q4" ///
				 1.treat#228.quarter = "2017q1" 1.treat#229.quarter = "2017q2" 1.treat#230.quarter = "2017q3" ///
				 1.treat#231.quarter = "2017q4" 1.treat#232.quarter = "2018q1" 1.treat#233.quarter = "2018q2" ///
				 1.treat#234.quarter = "2018q3" 1.treat#235.quarter = "2018q4", labsize(small) angle(45)) ///
				 ytitle("Coef: `lab'") yscale(titlegap(3)) xline(8.5, lp(dash) lw(thin) lc(black)) legend(size(vsmall)) ylabel(, angle(0))
		graph export "$figures/did3_`var'.pdf", replace
	}
	
	
